<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\BaseController;
use App\Http\Controllers\Controller;
use App\Models\Category;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class CategoryController extends BaseController
{
    public function index()
    {
        $this->setPageTitle('Category List');
        $data = Category::all();
        return view('admin.product-category.index', compact('data'));
    }

    public function addCategory(Request $request)
    {
        $this->setPageTitle('Category Add');
        if ($request->isMethod('post')) {

            $request->validate([
                'name' => 'required|unique:categories',
                'parent_id' => 'nullable'
            ]);
            DB::beginTransaction();
            try {
                $isCategoryCreated = Category::create([
                    'name' => $request['name'],
                    'parent_id' => $request['parent_id'] && $request['parent_id'] > 0 ? $request['parent_id'] : NULL,
                    'description' => $request['description'],
                    'created_by' => auth()->user()->id,
                    'updated_by' => auth()->user()->id
                ]);
                // if ($isCategoryCreated) {
                //     if (isset($request['category_image'])) {
                //         foreach ($request['category_image'] as $image) {
                //             $fileName = uniqid() . '.' . $image->getClientOriginalExtension();
                //             $isFileUploaded = $this->uploadOne($image, config('constants.SITE_CATEGORY_IMAGE_UPLOAD_PATH'), $fileName, 'public');

                //             if ($isFileUploaded) {
                //                 $isFileRelatedMediaCreated = $isCategoryCreated->media()->create([
                //                     'user_id' => auth()->user()->id,
                //                     'mediaable_type' => get_class($isCategoryCreated),
                //                     'mediaable_id' => $isCategoryCreated->id,
                //                     'media_type' => 'image',
                //                     'file' => $fileName,
                //                     'is_profile_picture' => false
                //                 ]);
                //             }
                //         }
                //     }
                // }
                if ($isCategoryCreated) {
                    DB::commit();
                    return $this->responseRedirect('admin.product.category.list', 'Category created successfully', 'success', false);
                }
            } catch (\Exception $e) {
                DB::rollback();
                logger($e->getMessage() . ' -- ' . $e->getLine() . ' -- ' . $e->getFile());
                return $this->responseRedirectBack('Something went wrong', 'error', true);
            }
        } else {
            return view('admin.product-category.add');
        }
    }

    public function editCategory(Request $request, $id)
    {
        $this->setPageTitle('Category Edit');
        if ($request->isMethod('post')) {

            $request->validate([
                'name' => 'required',
                'parent_id' => 'nullable'
            ]);
            DB::beginTransaction();
            try {
                $isCategoryCreated = Category::where('uuid', $id)->update([
                    'name' => $request['name'],
                    'parent_id' => $request['parent_id'] && $request['parent_id'] > 0 ? $request['parent_id'] : NULL,
                    'description' => $request['description'],
                    'created_by' => auth()->user()->id,
                    'updated_by' => auth()->user()->id
                ]);
                // if ($isCategoryCreated) {
                //     if (isset($request['category_image'])) {
                //         foreach ($request['category_image'] as $image) {
                //             $fileName = uniqid() . '.' . $image->getClientOriginalExtension();
                //             $isFileUploaded = $this->uploadOne($image, config('constants.SITE_CATEGORY_IMAGE_UPLOAD_PATH'), $fileName, 'public');

                //             if ($isFileUploaded) {
                //                 $isFileRelatedMediaCreated = $isCategoryCreated->media()->create([
                //                     'user_id' => auth()->user()->id,
                //                     'mediaable_type' => get_class($isCategoryCreated),
                //                     'mediaable_id' => $isCategoryCreated->id,
                //                     'media_type' => 'image',
                //                     'file' => $fileName,
                //                     'is_profile_picture' => false
                //                 ]);
                //             }
                //         }
                //     }
                // }
                if ($isCategoryCreated) {
                    DB::commit();
                    return $this->responseRedirect('admin.product.category.list', 'Category updated successfully', 'success', false);
                }
            } catch (\Exception $e) {
                DB::rollback();
                logger($e->getMessage() . ' -- ' . $e->getLine() . ' -- ' . $e->getFile());
                return $this->responseRedirectBack('Something went wrong', 'error', true);
            }
        } else {
            $data = Category::where('uuid', $id)->first();
            return view('admin.product-category.edit', compact('data'));
        }
    }



    public function deleteCategory()
    {

    }
}
