<?php

namespace App\Http\Controllers\Api\Customer;
use Auth;

use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;
use App\Services\User\UserService;
use Illuminate\Support\Facades\Hash;
use App\Http\Controllers\BaseController;
use Illuminate\Support\Facades\Validator;
use App\Http\Resources\Api\Agent\UserApiCollection;
use App\Http\Resources\Api\Customer\UserDetailApiCollection;
use App\Http\Resources\Api\Customer\UserProfileImageDetailApiCollection;

class UserApiControllers extends BaseController
{
    //

    protected $userService;

    public function __construct( UserService $userService) {
        $this->userService = $userService;
    }
    /**
     * @OA\post(
     *      path="api/customers/login-send-otp",
     *      tags={"customersLogin"},
     *      operationId="customersLogin",
     *      summary="customers send otp",
     *      description="Customer Send otp email and mobile",
     *      @OA\Parameter(
     *          name="mobile_number",
     *          description="Mobile Number",
     *          required=true,
     *          in="path",
     *          @OA\Schema(
     *              type="string"
     *          )
     *      ),
     *      @OA\Parameter(
     *          name="is_signup",
     *          description="this request is for singup true or false",
     *          required=true,
     *          in="path",
     *          @OA\Schema(
     *              type="boolean"
     *          )
     *      ),
     *      @OA\Parameter(
     *          name="email",
     *          description="Email",
     *          required=true,
     *          in="path",
     *          @OA\Schema(
     *              type="string"
     *          )
     *      ),
     *      @OA\Response(
     *          response=200,
     *          description="Successful operation",
     *       ),
     *      @OA\Response(
     *          response=400,
     *          description="Bad Request"
     *      ),
     *      @OA\Response(
     *          response=401,
     *          description="Unauthenticated",
     *      ),
     *      @OA\Response(
     *          response=403,
     *          description="Forbidden"
     *      )
     * )
     */
    public function loginSendOtp(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'is_signup'=>'required|boolean',
            'password'=>'required|string|min:6',
            'mobile_number' => Rule::requiredIf($request->email=="").'|nullable|string|min:10',
            'email' => Rule::requiredIf($request->mobile=="").'|nullable|string|email',
        ]);
        if($request->is_signup)
        {
            $validator = Validator::make($request->all(), [
                'is_signup'=>'required|boolean',
                'otp'=>'required|min:6',
                'mobile_number' => Rule::requiredIf($request->email=="").'|nullable|unique:users,mobile_number|string|min:10',
                'email' => Rule::requiredIf($request->mobile=="").'|nullable|unique:users,email|string|email',
            ]);
        }
        if ($validator->fails()) {
            $error=['error' => $validator->errors()->all()];
            return $this->responseJson(false,200,$validator->errors()->all(),"");
        }
        if($request->is_signup==0)
        {
            if($request->email)
            {
                $userExist = $this->userService->findUserByEmail($request->email);
            }else if($request->mobile_number)
            {
                $userExist = $this->userService->findUserByMobile($request->mobile_number);
            }
        }
        else
        {
            // echo "in";
            $userExist = $this->userService->createOrUpdateCustomer($request->except('_token'));
            $userData = new UserApiCollection($userExist);
            $message = "User Logged in successfully";
            return $this->responseJson(true, 200,$message,$userData);
        }
        // return $userExist;
        if ($userExist) {
            $userData=['otp'=>genrateOtp(),'user_details'=>$userExist];
            $message = "User Logged in successfully";
            return $this->responseJson(true, 200,$message,$userData);
        } else {
            $message = "Unauthorised";
            return $this->responseJson(false,401,$message,"");
            // return response()->json(['error' => 'Unauthorised'], 401);
        }
    }

    public function getGuidanceList()
    {
        $toReturn =[
            'guidances'=>getGuidance(),

        ];
        return $this->responseJson(true, 200,"",$toReturn);
    }

    public function signup(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'password'=>'required|string|min:6',
            'username' =>'required|nullable|string',
            'is_email'=>'required|boolean'
        ]);
        if ($validator->fails()) {
            $error=['error' => $validator->errors()->all()];
            return $this->responseJson(false,200,$validator->errors()->first(),"");
        }
        if($request->is_email)
        {
            $request->merge(['email'=>$request->username]);
            $userFound = $this->userService->findUserByEmail($request->username);
        }else
        {
            $request->merge(['mobile_number'=>$request->username]);
            $userFound = $this->userService->findUserByMobile($request->username);
        }
        if(!empty($userFound))
        {
            return $this->responseJson(false,200,"You have already registered","");
        }
       // return $request->all();
        $otp = genrateOtp(4);
        $request->merge(['verification_code'=>$otp]);
        $request->merge(['password'=>$request->password]);

        $userExist = $this->userService->createOrUpdateCustomer($request->except('_token'),$userFound?->id ?? NULL);
        // return $userExist;
        if ($userExist) {
            $userData=['otp'=>$otp];
            $message = "OTP send successfully !!";
            return $this->responseJson(true, 200,$message,$userData);
        } else {
            $message = "user not found";
            return $this->responseJson(false,401,$message,"");
            // return response()->json(['error' => 'Unauthorised'], 401);
        }
    }

    public function verifyOtp(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'otp'=>'required|numeric|digits:4',
            'username' =>'required|nullable|string',
            'is_email'=>'required|boolean'
        ]);
        if ($validator->fails()) {
            $error=['error' => $validator->errors()->all()];
            return $this->responseJson(false,200,$validator->errors()->first(),"");
        }
        if($request->is_email)
        {
            $request->merge(['email'=>$request->username]);
            $userFound = $this->userService->findUserByEmail($request->username);
        }else
        {
            $request->merge(['mobile_number'=>$request->username]);
            $userFound = $this->userService->findUserByMobile($request->username);
        }
        if(is_null($userFound)){
            return $this->responseJson(false, 200,"User Not Found","");
        }
        //return $userFound;
        if($request->otp!=$userFound->verification_code)
        {
            return $this->responseJson(false,200,"OTP not matched","");
        }else{
            $userFound->access_token = $userFound->createToken('LaravelAuthApp')->accessToken;
            $userData=['otp_matched'=>true,
            'user_details'=>$userFound
        ];
            $message = "OTP  Validated !!";
            return $this->responseJson(true, 200,$message,$userData);
        }

    }
    public function resendOtp(Request $request)
    {
        $validator = Validator::make($request->all(), [
            /* 'otp'=>'required|numeric|digits:4', */
            'username' =>'required|nullable|string',
            'is_email'=>'required|boolean'
        ]);
        if ($validator->fails()) {
            $error=['error' => $validator->errors()->all()];
            return $this->responseJson(false,200,$validator->errors()->first(),"");
        }
        if($request->is_email)
        {
            $request->merge(['email'=>$request->username]);
            $userFound = $this->userService->findUserByEmail($request->username);
        }else
        {
            $request->merge(['mobile_number'=>$request->username]);
            $userFound = $this->userService->findUserByMobile($request->username);
        }
        if(is_null($userFound)){
            return $this->responseJson(false, 200,"User Not Found","");
        }

        $otp = genrateOtp(4);
        $otpupdate = User::where('id',$userFound->id)->update([
                    'verification_code'=>$otp
        ]);
        if($otpupdate){
             $userData=[
            'otp'=>$otp
        ];
            $message = "OTP  Sent Successfully !!";
            return $this->responseJson(true, 200,$message,$userData);
        }else{
            return $this->responseJson(false,200,"Something Went Wrong","");
        }
        //return $userFound;
        /* if($request->otp!=$userFound->verification_code)
        {
            return $this->responseJson(false,200,"OTP not matched","");
        }else{
            $userFound->access_token = $userFound->createToken('LaravelAuthApp')->accessToken;
            $userData=['otp_matched'=>true,
            'user_details'=>$userFound
        ];
            $message = "OTP  Validated !!";
            return $this->responseJson(true, 200,$message,$userData);
        } */

    }

    public function login(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'password'=>'required|string|min:6',
            'username' =>'required|nullable|string',
            'is_email'=>'required|boolean'
        ]);
        if ($validator->fails()) {
            $error=['error' => $validator->errors()->all()];
            return $this->responseJson(false,200,$validator->errors()->first(),"");
        }
        if($request->is_email)
        {
            $loginParam= ['email'=>$request->username];
        }else
        {
            $loginParam= ['mobile_number'=>$request->username];
        }
        $loginParam['password']=$request->password;
        if(auth()->attempt($loginParam))
        {
           $otp = genrateOtp(4);
           $user= auth()->user();
            $otpupdate = $user->update([
                        'verification_code'=>$otp
            ]);
            if($otpupdate) {
            $userData=[
            'otp'=>$otp
            ];
            $message = "OTP  Sent Successfully !!";
            return $this->responseJson(true, 200, $message, $userData);
            }
        }
        else{
            return $this->responseJson(false,200,"Wrong login details","");
        }
    }


    public function loginVerify(Request $request){

       $validator = Validator::make($request->all(), [
            'otp'=>'required|numeric|digits:4',
            'username' =>'required|nullable|string',
            'is_email'=>'required|boolean'
        ]);
        if ($validator->fails()) {
            $error=['error' => $validator->errors()->all()];
            return $this->responseJson(false,200,$validator->errors()->first(),"");
        }
        if($request->is_email)
        {
            $request->merge(['email'=>$request->username]);
            $userFound = $this->userService->findUserByEmail($request->username);
        }else
        {
            $request->merge(['mobile_number'=>$request->username]);
            $userFound = $this->userService->findUserByMobile($request->username);
        }
        if(is_null($userFound)){
            return $this->responseJson(false, 200,"User Not Found","");
        }
        //return $userFound;
        if($request->otp!=$userFound->verification_code)
        {
            return $this->responseJson(false,200,"OTP not matched","");
        }else{
            $userFound->access_token = $userFound->createToken('LaravelAuthApp')->accessToken;
            $userData=['otp_matched'=>true,
            'user_details'=>$userFound
        ];
            $message = "LoggedIn Successfully !!";
            return $this->responseJson(true, 200,$message,$userData);
        }
    }
    public function forgotPassword(Request $request){
         $validator = Validator::make($request->all(), [
           /*  'otp'=>'required|numeric|digits:4', */
            'username' =>'required|nullable|string',
            'is_email'=>'required|boolean'
        ]);
        if ($validator->fails()) {
            $error=['error' => $validator->errors()->all()];
            return $this->responseJson(false,200,$validator->errors()->first(),"");
        }
        if($request->is_email)
        {
            $request->merge(['email'=>$request->username]);
            $userFound = $this->userService->findUserByEmail($request->username);
        }else
        {
            $request->merge(['mobile_number'=>$request->username]);
            $userFound = $this->userService->findUserByMobile($request->username);
        }
        if(is_null($userFound)){
            return $this->responseJson(false, 200,"User Not Found","");
        }
        //return $userFound;
        $otp = genrateOtp(4);
        $otpupdate = User::where('id',$userFound->id)->update([
                    'verification_code'=>$otp
        ]);
        if($otpupdate){
             $userData=[
            'otp'=>$otp
        ];
            $message = "OTP  Sent Successfully !!";
            return $this->responseJson(true, 200,$message,$userData);
        }else{
            return $this->responseJson(false,200,"Something Went Wrong","");
        }
    }
    public function createPassword(Request $request){
        $validator = Validator::make($request->all(), [
            'new_password' => 'required|min:8|string',
            'confirm_password' => 'required|same:new_password',
            'username'              =>'required|string',
            'is_email'              =>'required|boolean'
        ]);
        if ($validator->fails()) {
            $error=['error' => $validator->errors()->all()];
            return $this->responseJson(false,200,$validator->errors()->first(),"");
        }
        if($request->is_email)
        {
            $request->merge(['email'=>$request->username]);
            $userFound = $this->userService->findUserByEmail($request->username);
        }else
        {
            $request->merge(['mobile_number'=>$request->username]);
            $userFound = $this->userService->findUserByMobile($request->username);
        }
        if(is_null($userFound)){
            return $this->responseJson(false, 200,"User Not Found","");
        }

         /* $otp = genrateOtp(4); */
        $otpupdate =  $this->userService->saveUserProfileDetails([
                    'password' => $request->new_password,
                    'is_password_changed' => 1,
                ], $userFound->id);

        if($otpupdate){
             /* $userData=[
            'otp'=>$otp
        ]; */
            $message = "Password  Created Successfully !!";
            return $this->responseJson(true, 200,$message,"");
        }else{
            return $this->responseJson(false,200,"Something Went Wrong","");
        }
    }
    public function createProfile(Request $request){
         $userId = auth()->user()->id;
        //  return $request->all();
        // if ($request->post()) {
            $validator = Validator::make($request->all(), [
                'name' => 'required|string',
                'gender' => 'required|string',
                'age' => 'required|string',
                'height' => 'required|nullable|string',
                'weight' => 'required|nullable|string',
                'target_weight' => 'required|nullable|string',
                'guidance' => 'required|nullable|string',
            ]);
            if ($validator->fails()) {
                $error=['error' => $validator->errors()->all()];
                return $this->responseJson(false,200,$validator->errors()->first(),"");
            }
            $guidance = is_array($request->guidance) ? $request->guidance : explode(",",$request->guidance);
            $request->merge(['guidance'=>$guidance]);
            //\DB::beginTransaction();
            /* try{ */
                $userData =  $this->userService->updateOrCreateProfile($request->all(), $userId);
                if($userData){
                    return $this->responseJson(true,200,"",new UserDetailApiCollection($userData));
                }
            /* }catch(\Exception $e){
                \DB::rollback();
                logger($e->getMessage() . ' -- ' . $e->getLine() . ' -- ' . $e->getFile());
                return $this->responseJson(false,200,"Something went wrong","");
            } */
        }
    /**
     * @OA\Get(
     *      path="/agent/user",
     *      tags={"getAgentDetail"},
     *      operationId="getAgentDetail",
     *      summary="Get Agent information",
     *      description="Get Agent information",
     *      @OA\Response(
     *          response=200,
     *          description="Successful operation",
     *       ),
     *      @OA\Response(
     *          response=400,
     *          description="Bad Request"
     *      ),
     *      @OA\Response(
     *          response=401,
     *          description="Unauthenticated",
     *      ),
     *      @OA\Response(
     *          response=403,
     *          description="Forbidden"
     *      )
     * )
     */
    public function userDetails(Request $request)
    {
        $user = auth()->user();
        $message = "User Details Fetched Successfully !!";
         $userData = new UserDetailApiCollection($user);
        return $this->responseJson([
            'status'        =>  true,
            'response_code' =>  200,
            'message'       =>  $message,
            'data'          =>  $userData
        ]);
    }

    

     /**
     * @OA\Post(
     *      path="/agent/logout",
     *      tags={"Agentlogout"},
     *      operationId="AgentLogout",
     *      summary="Agent Logout",
     *      description="Agent Logout",
     *      @OA\Response(
     *          response=200,
     *          description="Successful operation",
     *       ),
     *      @OA\Response(
     *          response=400,
     *          description="Bad Request"
     *      ),
     *      @OA\Response(
     *          response=401,
     *          description="Unauthenticated",
     *      ),
     *      @OA\Response(
     *          response=403,
     *          description="Forbidden"
     *      )
     * )
     */
    public function logout(Request $request)
    {
        $user = auth()->user();
        $message = "User Logged Out successfully";

        return $this->responseJson([
            'status'        =>  true,
            'response_code' =>  200,
            'message'       =>  $message,
            'data'          =>  $user
        ]);
    }
    /**
     * @OA\post(
     *      path="api/agent/change-password",
     *      tags={"agentChangePassword"},
     *      operationId="agentChangePassword",
     *      summary="ChangePassword",
     *      description="ChangePassword information",
     *      @OA\Parameter(
     *          name="new_password",
     *          description="new_password",
     *          required=true,
     *          in="path",
     *          @OA\Schema(
     *              type="string"
     *          )
     *      ),
     *      @OA\Parameter(
     *          name="confirm_password",
     *          description="confirm_password",
     *          required=true,
     *          in="path",
     *          @OA\Schema(
     *              type="string"
     *          )
     *      ),
     *      @OA\Response(
     *          response=200,
     *          description="Successful operation",
     *       ),
     *      @OA\Response(
     *          response=400,
     *          description="Bad Request"
     *      ),
     *      @OA\Response(
     *          response=401,
     *          description="Unauthenticated",
     *      ),
     *      @OA\Response(
     *          response=403,
     *          description="Forbidden"
     *      )
     * )
     */
    public function changePassword(Request $request)
    {
        $userId = auth()->user()->id;
        // if ($request->post()) {
            $validator = Validator::make($request->all(), [
                'old_password' => 'required|string',
                'new_password' => 'required|min:8|string'
            ]);
            if ($validator->fails()) {
                $error=['error' => $validator->errors()->all()];
                return $this->responseJson(false,200,$validator->errors()->all(),"");
            }
           /*  $user = auth()->user(); */
           $userDetails = User::where('id',$userId)->first();
                if(!Hash::check($request->input('old_password'), $userDetails->password)):
                    $message = "Old Password Does Not Match!";
                    return $this->responseJson([
                        'status'        =>  false,
                        'response_code' =>  200,
                        'message'       =>  $message,
                        'data'          =>  ""
                    ]);
                    /* return response()->json([
                        'status'    => FALSE,
                        'message'   =>'Old Password Does Not Match!',
                        'data'      => $this->object
                    ],403); */
                else:
                    User::where('id',$userId)
                            ->update([
                                'password'=> Hash::make($request->input('new_password')),
                                'is_password_changed' => 1
                            ]);
                    $message = "Password Updated successfully";
                    return $this->responseJson([
                        'status'        =>  true,
                        'response_code' =>  200,
                        'message'       =>  $message,
                        'data'          =>  ""
                    ]);
                endif;
              /* $userData = new UserApiCollection($user);
                $isProcessed = $this->userService->saveUserProfileDetails([
                    'password' => $request->new_password,
                    'is_password_changed' => 1,
                ], $userId);
                if ($isProcessed) {
                    $message = "Password changed in successfully";
                    return $this->responseJson([
                        'status'        =>  true,
                        'response_code' =>  200,
                        'message'       =>  $message,
                        'data'          =>  $userData
                    ]);

            } else {
                $message = "Something went wrong please try again";
                return $this->responseJson([
                    'status'        =>  false,
                    'response_code' =>  200,
                    'message'       =>  $message,
                    'data'          =>  ""
                ]);
            } */
    }

    public function profileImageupdate(Request $request){

        $userId = auth()->user()->id;
        $validator = Validator::make($request->all(), [
                "customer_image" => 'required|file|mimes:jpg,png,gif,jpeg'
            ]);
            if ($validator->fails()) {
                $error=['error' => $validator->errors()->all()];
                return $this->responseJson(false,200,$validator->errors()->first(),"");
            }
            //\DB::beginTransaction();
        /* try{ */
            $userData =  $this->userService->updateOrCreateProfileImage($request->all(), $userId);
            if($userData){
                return $this->responseJson(true,200,"Profile Image Updated Successfully",new UserProfileImageDetailApiCollection($userData));
            }
    }

}
