<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Webpatser\Uuid\Uuid;


class Diet extends Model
{
    use HasFactory, SoftDeletes;

    protected $fillable = [
        'uuid',
        'gender',
        'age_from',
        'age_from',
        'height_from',
        'height_to',
        'weight_from',
        'weight_to',
        'bmi',
        'goal',
        'diet',
        'medical_condition',
        'allergy',
        'status',
        'created_at',
        'updated_at',
    ];

    public static function boot()
    {
        parent::boot();
        self::creating(function ($model) {
            $model->uuid = (string) Uuid::generate(4);
        });
        self::deleting(function ($query) { // before delete() method call this
            $query->breakfasts()->delete();
        });
        self::deleting(function ($query) { // before delete() method call this
            $query->lunches()->delete();
        });
        self::deleting(function ($query) { // before delete() method call this
            $query->snacks()->delete();
        });
        self::deleting(function ($query) { // before delete() method call this
            $query->dinners()->delete();
        });
    }

    public function breakfasts()
    {
        return $this->hasMany(DietBreakfast::class);
    }
    public function lunches()
    {
        return $this->hasMany(DietLunch::class);
    }
    public function snacks()
    {
        return $this->hasMany(DietSnack::class);
    }
    public function dinners()
    {
        return $this->hasMany(DietDinner::class);
    }
}
