<?php

namespace App\Models;

use App\Traits\HasRolesAndPermissions as TraitsHasRolesAndPermissions;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
// use Laravel\Sanctum\HasApiTokens;
use Laravel\Passport\HasApiTokens;
use Webpatser\Uuid\Uuid;

class User extends Authenticatable implements MustVerifyEmail
{
    use HasApiTokens, HasFactory, Notifiable, SoftDeletes, TraitsHasRolesAndPermissions;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $appends = [
        'profile_picture',
        // 'login_id'
        // 'logo_picture'
    ];
    public static function boot()
    {
        parent::boot();
        self::creating(function ($model) {
            $model->uuid = (string) Uuid::generate(4);
        });
        /* self::deleting(function ($query) {
            $query->personalDetail()->delete();
        });
        self::deleting(function ($query) {
            $query->familyDetails()->delete();
        });
        self::deleting(function ($query) {
            $query->propertyDetails()->delete();
        });
        self::deleting(function ($query) {
            $query->otherLoansDetails()->delete();
        });
        self::deleting(function ($query) {
            $query->bankDetails()->delete();
        });
        self::deleting(function ($query) {
            $query->kycDetails()->delete();
        });
        self::deleting(function ($query) {
            $query->branches()->detach();


        }); */
        /* self::deleting(function ($query) {
            $query->roles()->detach();
        }); */
    }
    protected $fillable = [
        'id',
        'first_name',
        'title',
        'last_name',
        'uuid',
        'email',
        'mobile_number',
        'password',
        'username',
        'login_id',
        'mfi_id',
        'email_verified_at',
        'is_profile_completed',
        'is_password_changed',
        'verification_code',
        'is_active',
        'is_blocked',
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'id',
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'two_factor_expires_at' => 'datetime',
        'notifications' => 'array',
        // 'address'                => 'array',
    ];

    public function generateUserName($userType, $name)
    {
        $number = mt_rand(100000, 999999);
        $username = $userType . substr($name, 3) . $number;
        if ($this->usernameexists($username)) {
            return $this->generateUsername($userType, $name);
        }
        return $username;
    }

    public function generateTwoFactorCode()
    {
        $this->timestamps = false;
        $this->two_factor_code = rand(10000, 99999);
        $this->two_factor_expires_at = now()->addMinutes(2);
        $this->save();
    }

    public function resetTwoFactorCode()
    {
        $this->timestamps = false;
        $this->two_factor_code = null;
        $this->two_factor_expires_at = null;
        $this->save();
    }

    public function profile()
    {
        return $this->hasOne(Profile::class, 'user_id');
    }

    public function personalDetail()
    {
        return $this->hasOne(CustomerPersonalDetail::class);
    }
    public function familyDetails()
    {
        return $this->hasMany(CustomerFamilyDetail::class);
    }
    public function propertyDetails()
    {
        return $this->hasMany(CustomerPropertyDetail::class);
    }
    public function otherLoansDetails()
    {
        return $this->hasMany(CustomerOtherLoanDetail::class);
    }

    public function bankDetails()
    {
        return $this->hasOne(CustomerBankDetail::class);
    }
    public function kycDetails()
    {
        return $this->hasOne(CustomerKycVerification::class);
    }

    public function device()
    {
        return $this->hasMany(Device::class);
    }
    public function mfi()
    {
        return $this->belongsTo(Mfi::class);
    }
    public function branch()
    {
        return $this->hasOne(UserBranch::class);
    }
    public function getProfilePictureAttribute()
    {
        return $this->profilePicture();
    }
    public function getLocationPictureAttribute()
    {
        return $this->locationPicture();
    }
    public function getAadhaarPictureAttribute()
    {
        return $this->aadhaarPicture();
    }
    public function getCustomerPictureAttribute()
    {
        return $this->profilePicture('original/user');
    }

    public function getFullNameAttribute()
    {
        return $this->first_name . (!is_null($this->last_name) ? ' ' . $this->last_name : '');
    }
    public function profilePicture($type = 'profile')
    {
        $profilePicture = $this->media()->where('is_profile_picture', 1)->value('file');
        if (!is_null($profilePicture)) {
            $fileDisk = config('constants.SITE_FILE_STORAGE_DISK');
            //return $fileDisk;
            if ($fileDisk == 'public') {
                $image = public_path('storage/images/' . $type . '/' . $profilePicture);
                //return $image;

                if (file_exists(public_path('storage/images/' . $type . '/' . $profilePicture))) {
                    return asset('storage/images/' . $type . '/' . $profilePicture);
                }
            }
        }
        return asset('assets/images/pro_img.jpg');
    }
    /*  public function kycPicture($type = 'profile')
    {
        $profilePicture = $this->media()->where('is_profile_picture', 1)->value('file');
        // return $profilePicture;
        if (!is_null($profilePicture)) {
            $fileDisk = config('constants.SITE_FILE_STORAGE_DISK');
            if ($fileDisk == 'public') {
                if (file_exists(public_path('storage/images/' . $type . '/' . $profilePicture))) {
                    return asset('storage/images/' . $type . '/' . $profilePicture);
                }
            }
        }
        return asset('assets/images/pro_img.jpg');
    } */
    public function locationPicture($type = 'location')
    {
        $locationPicture = $this->media()->where('is_location', 1)->value('file');
        // return $profilePicture;
        if (!is_null($locationPicture)) {

            $fileDisk = config('constants.SITE_FILE_STORAGE_DISK');
            if ($fileDisk == 'public') {
                if (file_exists(public_path('storage/images/original/' . $type . '/' . $locationPicture))) {
                    return asset('storage/images/original/' . $type . '/' . $locationPicture);
                }
            }
        }

        return asset('assets/images/pro_img.jpg');
    }
    public function aadhaarPicture($type = 'aadhaar')
    {
        $aadhaarPicture = $this->media()->where('is_aadhaar', 1)->value('file');
        // return $profilePicture;
        if (!is_null($aadhaarPicture)) {

            $fileDisk = config('constants.SITE_FILE_STORAGE_DISK');
            if ($fileDisk == 'public') {
                if (file_exists(public_path('storage/images/original/' . $type . '/' . $aadhaarPicture))) {
                    return asset('storage/images/original/' . $type . '/' . $aadhaarPicture);
                }
            }
        }

        return asset('assets/images/pro_img.jpg');
    }
    /* public function logoImage($type = 'logo') {
    // return true;
    $logoPicture = $this->media()->where('is_logo', 1)->value('file');
    //return $logoPicture;
    if(!is_null($logoPicture)){

    $fileDisk = config('constants.SITE_FILE_STORAGE_DISK');
    if($fileDisk == 'public'){
    if(file_exists(public_path('storage/images/original/'.$type.'/'. $logoPicture))){
    return asset('storage/images/original/'.$type.'/'. $logoPicture);
    }
    }
    }
    return asset('assets/images/no-logo.jpg');
    } */
    public function mediaImage()
    {
        return $this->morphOne('App\Models\Media', 'mediaable')->where('deleted_at', null)->orderBy('id', 'DESC');
    }
    public function media(): HasMany
    {
        return $this->hasMany(Media::class, 'user_id', 'id');
    }

    public function branches()
    {
        return $this->belongsToMany(Branch::class, 'user_branches');
    }
    /* public function roles(){
    return $this->belongsToMany(Role::class, 'user_roles');
    } */

    public function document()
    {
        return $this->morphMany(Document::class, 'documentable');
    }
    public function demands()
    {
        return $this->hasMany(CustomerDemand::class, 'user_id')->orderBy('id', 'desc');
    }
    public function pendingDemands()
    {
        return $this->hasMany(CustomerDemand::class, 'user_id')->orderBy('id', 'desc');
    }
    public function address()
    {
        return $this->morphOne(Address::class, 'addressable');
    }

    public function scopeActive($query, $type)
    {
        return $query->whereHas(
            'roles',
            function ($q) use ($type) {
                $q->where('slug', $type);
            }
        )->where('is_active', '1');
    }

    public function scopeInactive($query, $type)
    {
        return $query->whereHas(
            'roles',
            function ($q) use ($type) {
                $q->where('slug', $type);
            }
        )->where('is_active', '0');
    }

    public function scopeUsernameexists($query, $username)
    {
        return $query->where('username', $username)->exists();
    }
    /* public function addressBook(){
return $this->hasOne(Address::class);
} */


    public function scopeListUser($query, $role = "", $excludeRoles = [])
    {
        $branch_ids = getAllBranchIds();
        // dd($branch_ids);
        $query->where('mfi_id', auth()->user()->mfi->id)->whereHas('branch', function ($q) use ($branch_ids) {
            $q->whereIn('branch_id', $branch_ids);
        });
        if (!empty($role)) {
            $query->whereHas('roles', function ($q) use ($role) {
                $q->where('slug', $role);
            });
        }
        if (!empty($excludeRoles) && count($excludeRoles)) {
            $query->whereHas('roles', function ($q) use ($excludeRoles) {
                $q->whereNotIn('slug', $excludeRoles);
            });
        }
        return $query;
    }
}
