<?php

use App\Http\Controllers\Admin\AttributeController;
use Illuminate\Support\Facades\Route;

Route::namespace('Admin')->as('admin.')->middleware(['auth'])->group(function () {

    Route::controller(MenuController::class)->prefix('menu')->as('menu.')->group(function () {
        Route::get('/', 'index')->name('list');
        Route::get('/add', 'create')->name('add');
        Route::get('/edit/{id}', 'edit')->name('edit');
        Route::post('/store', 'store')->name('store');
        Route::post('/update/{id}', 'update')->name('update');
    });
    Route::controller(AdminController::class)->group(function () {
        Route::get('/dashboard', 'index')->name('home');
        Route::match(['get', 'post'], '/change-password', 'changePassword')->name('change.password');
        Route::match(['get', 'post'], '/profile', 'profile')->name('profile');
        Route::get('/admin-users', 'adminUser')->name('user.list');
        Route::match(['get', 'post'], '/admin-users/edit/{uuid}', 'adminUserEdit')->name('user.edit');
    });
    Route::controller(InvitationController::class)->as('invitation.')->group(function () {
        Route::get('/invitation-list', 'list')->name('list');
        Route::get('/create', 'create')->name('create');
        Route::post('/store', 'store')->name('store');
        Route::match(['get', 'post'], '/{uuid}/attach-permission', 'attachPermission')->name('attach.permission');
    });
    Route::controller(RoleController::class)->as('role.')->prefix('roles')->group(function () {
        Route::get('/', 'listRoles')->name('list');
        Route::get('/add', 'addRoles')->name('add');
        Route::post('/save', 'saveRoles')->name('save');
        Route::match(['get', 'post'], '/{id}/attach-permission', 'attachPermission')->name('attach.permission');
    });
    Route::controller(CustomerController::class)->as('customer.')->prefix('customers')->group(function () {
        Route::get('/', 'index')->name('list');
        Route::get('/add', 'addCustomers')->name('add');
        Route::post('/save', 'store')->name('save');
        Route::match(['get', 'post', 'put'], 'edit/{uuid}', 'editCustomers')->name('edit');
        Route::get('/delete/{uuid}', 'deleteCustomers')->name('delete');
        Route::get('/view-address/{uuid}', 'viewAddress')->name('view.address');
        Route::match(['get', 'post'], '/update-address/{uuid}', 'editAddress')->name('update.address');
    });
    Route::controller(FaqController::class)->as('faq.')->prefix('faqs')->group(function () {
        Route::get('/', 'index')->name('list');
        Route::match(['get', 'post'], 'add', 'addFaq')->name('add');
        Route::match(['get', 'post', 'put'], 'edit/{uuid}', 'editFaq')->name('edit');
        Route::get('/delete/{uuid}', 'deleteFaq')->name('delete');
    });
    Route::controller(PagesController::class)->as('page.')->prefix('pages')->group(function () {
        Route::get('/', 'viewPage')->name('list');
        Route::match(['get', 'post'], 'add', 'addPage')->name('add');
        Route::match(['get', 'post', 'put'], 'edit/{uuid}', 'editPage')->name('edit');
        Route::get('/delete/{uuid}', 'deletePage')->name('delete');
    });
    Route::controller(DietPlanController::class)->as('diet.')->prefix('diet')->group(function () {
        Route::get('/', 'dietPlanList')->name('list');
        /* Route::get('/add', 'addCustomers')->name('add');
        Route::post('/save', 'store')->name('save');
        Route::match(['get', 'post', 'put'], 'edit/{uuid}', 'editCustomers')->name('edit');
        Route::get('/delete/{uuid}', 'deleteCustomers')->name('delete');
        Route::get('/view-address/{uuid}', 'viewAddress')->name('view.address');
        Route::match(['get', 'post'], '/update-address/{uuid}', 'editAddress')->name('update.address'); */
    });

    Route::controller(CategoryController::class)->as('product.category.')->prefix('product/category')->group(function () {
        Route::get('/', 'index')->name('list');
        Route::match(['get', 'post'], 'add', 'addCategory')->name('add');
        Route::match(['get', 'post', 'put'], 'edit/{uuid}', 'editCategory')->name('edit');
        Route::get('/delete/{uuid}', 'deleteCategory')->name('delete');
    });

    Route::controller(AttributeController::class)->as('product.attribute.')->prefix('product/attribute')->group(function () {
        Route::get('/', 'index')->name('list');
        Route::match(['get', 'post'], 'add', 'addAttribute')->name('add');
        Route::match(['get', 'post', 'put'], 'edit/{uuid}', 'editAttribute')->name('edit');
        Route::get('/delete/{uuid}', 'deleteAttribute')->name('delete');
    });

    Route::controller(ProductController::class)->as('product.')->prefix('product')->group(function () {
        Route::get('/', 'index')->name('list');
        Route::match(['get', 'post'], 'add', 'addProduct')->name('add');
        Route::match(['get', 'post', 'put'], 'edit/{uuid}', 'editProduct')->name('edit');
        Route::get('/delete/{uuid}', 'deleteProduct')->name('delete');
    });

    Route::prefix('subscription')->as('subscription.')->group(function () {
        Route::controller(PlanCategoryController::class)->prefix('categories')->as('category.')->group(function () {
            Route::get('/', 'viewCategory')->name('list');
            Route::get('details/{uuid}', 'categoryDetails')->name('view');
            Route::match(['get', 'post'], 'add', 'addCategory')->name('add');
            Route::match(['get', 'post', 'put'], 'edit/{uuid}', 'editCategory')->name('edit');
            Route::post('/getCategories', 'getCategory')->name('get.categories');
            Route::get('/delete/{uuid}', 'deleteCategory')->name('delete');
        });
        Route::controller(CourseController::class)->as('course.')->prefix('courses')->group(function () {
            Route::get('/course-list', 'courseList')->name('list');
            Route::match(['get', 'post'], 'add', 'addCourse')->name('add');
            Route::match(['get', 'post', 'put'], 'edit/{uuid}', 'editCourse')->name('edit');
            Route::get('/delete/{uuid}', 'deleteCourse')->name('delete');
        });
    });
});

Route::post('admin/logout', 'Auth\LoginController@adminLogout')->name('admin.logout');

Route::get('/', 'Admin\MfiController@mfiList')->name('mfi-list');
